@@ -1,5 +1,7 @@
 package Perl::Critic::Policy::OTRS::ProhibitLocaltime;
 
+# ABSTRACT: do not use "localtime"
+
 use strict;
 use warnings;
 
@@ -28,15 +30,16 @@ sub violates {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
 
-Perl::Critic::Policy::OTRS::ProhibitLocaltime
+Perl::Critic::Policy::OTRS::ProhibitLocaltime - do not use "localtime"
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 AUTHOR
 
@@ -51,4 +54,3 @@ This is free software, licensed under:
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
