@@ -1,5 +1,7 @@
 package Perl::Critic::Policy::OTRS::ProhibitOpen;
 
+# ABSTRACT: Do not use "open"
+
 use strict;
 use warnings;
 
@@ -27,17 +29,17 @@ sub violates {
 
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
 
-Perl::Critic::Policy::OTRS::ProhibitOpen
+Perl::Critic::Policy::OTRS::ProhibitOpen - Do not use "open"
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 AUTHOR
 
@@ -52,4 +54,3 @@ This is free software, licensed under:
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
