@@ -1,5 +1,7 @@
 package Perl::Critic::Policy::OTRS::ProhibitRmtree;
 
+# ABSTRACT: Do not use File::Path's rmtree
+
 use strict;
 use warnings;
 
@@ -34,15 +36,16 @@ sub violates {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
 
-Perl::Critic::Policy::OTRS::ProhibitRmtree
+Perl::Critic::Policy::OTRS::ProhibitRmtree - Do not use File::Path's rmtree
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 AUTHOR
 
@@ -57,4 +60,3 @@ This is free software, licensed under:
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
