@@ -1,5 +1,7 @@
 package Perl::Critic::Policy::OTRS::RequireParensWithMethods;
 
+# ABSTRACT: Use parens when a method is called
+
 use strict;
 use warnings;
 
@@ -10,7 +12,7 @@ use Readonly;
 
 our $VERSION = '0.01';
 
-Readonly::Scalar my $DESC => q{Method invokation should use "()"};
+Readonly::Scalar my $DESC => q{Method invocation should use "()"};
 Readonly::Scalar my $EXPL => q{Use "->MethodName()" instead of "->MethodName".};
 
 sub supported_parameters { return; }
@@ -40,15 +42,16 @@ sub violates {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
 
-Perl::Critic::Policy::OTRS::RequireParensWithMethods
+Perl::Critic::Policy::OTRS::RequireParensWithMethods - Use parens when a method is called
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 AUTHOR
 
@@ -63,4 +66,3 @@ This is free software, licensed under:
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
